@@ -32,14 +32,8 @@ using namespace std;
 
 using pws_os::CUUID;
 
-// hide w_char/char differences where possible:
-#ifdef UNICODE
 typedef std::wifstream ifstreamT;
 typedef std::wofstream ofstreamT;
-#else
-typedef std::ifstream ifstreamT;
-typedef std::ofstream ofstreamT;
-#endif
 typedef std::vector<stringT>::iterator viter;
 
 extern const TCHAR *GROUPTITLEUSERINCHEVRONS;
@@ -202,7 +196,7 @@ void PWScore::Compare(PWScore *pothercore,
         CompareField(CItemData::RMTIME, bsFields, currentItem, compItem, bsConflicts);
 
         if (bsFields.test(CItemData::XTIME_INT)) {
-          int current_xint, comp_xint;
+          int32 current_xint, comp_xint;
           currentItem.GetXTimeInt(current_xint);
           compItem.GetXTimeInt(comp_xint);
           if (current_xint != comp_xint)
@@ -476,7 +470,7 @@ stringT PWScore::Merge(PWScore *pothercore,
 
       stringT str_diffs(_T("")), str_temp;
       int diff_flags = 0;
-      int cxtint, oxtint;
+      int32 cxtint, oxtint;
       time_t cxt, oxt;
       if (otherItem.GetPassword() != curItem.GetPassword()) {
         diff_flags |= MRG_PASSWORD;
@@ -606,7 +600,7 @@ stringT PWScore::Merge(PWScore *pothercore,
         // have a match on group/title/user, but not on other fields
         // add an entry suffixed with -merged-YYYYMMDD-HHMMSS
         StringX sx_newTitle;
-        Format(sx_newTitle, _T("%s-%s-%s"), sx_otherTitle.c_str(), sx_merged.c_str(),
+        Format(sx_newTitle, L"%ls-%ls-%ls", sx_otherTitle.c_str(), sx_merged.c_str(),
                             str_timestring.c_str());
 
         // note it as an issue for the user
@@ -740,7 +734,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                     str_singular_plural_verb.c_str());
     pRpt->WriteLine(str_results.c_str());
     for (size_t i = 0; i < vs_added.size(); i++) {
-      Format(str_results, _T("\t%s"), vs_added[i].c_str());
+      Format(str_results, L"\t%ls", vs_added[i].c_str());
       pRpt->WriteLine(str_results.c_str());
     }
   }
@@ -754,7 +748,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                     str_singular_plural_verb.c_str());
     pRpt->WriteLine(str_results.c_str());
     for (size_t i = 0; i < vs_AliasesAdded.size(); i++) {
-      Format(str_results, _T("\t%s"), vs_AliasesAdded[i].c_str());
+      Format(str_results, _T("\t%ls"), vs_AliasesAdded[i].c_str());
       pRpt->WriteLine(str_results.c_str());
     }
   }
@@ -768,7 +762,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                     str_singular_plural_verb.c_str());
     pRpt->WriteLine(str_results.c_str());
     for (size_t i = 0; i < vs_ShortcutsAdded.size(); i++) {
-      Format(str_results, _T("\t%s"), vs_ShortcutsAdded[i].c_str());
+      Format(str_results, L"\t%ls", vs_ShortcutsAdded[i].c_str());
       pRpt->WriteLine(str_results.c_str());
     }
   }
@@ -843,7 +837,7 @@ int PWScore::MergeDependents(PWScore *pothercore, MultiCommands *pmulticmds,
     StringX sx_newTitle = ci_temp.GetTitle();
     if (bTitleRenamed) {
       StringX sx_otherTitle(sx_newTitle);
-      Format(sx_newTitle, _T("%s%s%s"), sx_otherTitle.c_str(),
+      Format(sx_newTitle, L"%ls%ls%ls", sx_otherTitle.c_str(),
                           sx_merged.c_str(), str_timestring.c_str());
       ci_temp.SetTitle(sx_newTitle);
     }
@@ -950,7 +944,7 @@ void PWScore::Synchronize(PWScore *pothercore,
       updItem.SetDisplayInfo(NULL);
 
       if (curItem.GetUUID() != otherItem.GetUUID()) {
-        pws_os::Trace(_T("Synchronize: Mis-match UUIDs for [%s:%s:%s]\n"),
+        pws_os::Trace(_T("Synchronize: Mis-match UUIDs for [%ls:%ls:%ls]\n"),
              sx_otherGroup.c_str(), sx_otherTitle.c_str(), sx_otherUser.c_str());
       }
 
@@ -1009,7 +1003,7 @@ void PWScore::Synchronize(PWScore *pothercore,
                     str_singular_plural_verb.c_str());
     pRpt->WriteLine(str_results.c_str());
     for (size_t i = 0; i < vs_updated.size(); i++) {
-      Format(str_results, _T("\t%s"), vs_updated[i].c_str());
+      Format(str_results, L"\t%ls", vs_updated[i].c_str());
       pRpt->WriteLine(str_results.c_str());
     }
   }
