@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -36,15 +36,11 @@ bool pws_os::FileExists(const stringT &filename)
 {
   struct stat statbuf;
   int status;
-#ifndef UNICODE
-  status = ::stat(filename.c_str(), &statbuf);
-#else
   size_t N = wcstombs(NULL, filename.c_str(), 0) + 1;
   char *fn = new char[N];
   wcstombs(fn, filename.c_str(), N);
   status = ::stat(fn, &statbuf);
   delete[] fn;
-#endif /* UNICODE */
   return (status == 0);
 }
 
@@ -52,12 +48,6 @@ bool pws_os::FileExists(const stringT &filename, bool &bReadOnly)
 {
   bool retval;
   bReadOnly = false;
-#ifndef UNICODE
-  retval = (::access(filename.c_str(), R_OK) == 0);
-  if (retval) {
-    bReadOnly = (::access(filename.c_str(), W_OK) != 0);
-  }
-#else
   size_t N = wcstombs(NULL, filename.c_str(), 0) + 1;
   char *fn = new char[N];
   wcstombs(fn, filename.c_str(), N);
@@ -66,16 +56,12 @@ bool pws_os::FileExists(const stringT &filename, bool &bReadOnly)
     bReadOnly = (::access(fn, W_OK) != 0);
   }
   delete[] fn;
-#endif /* UNICODE */
   return retval;
 }
 
 bool pws_os::RenameFile(const stringT &oldname, const stringT &newname)
 {
   int status;
-#ifndef UNICODE
-  status = ::rename(oldname.c_str(), newname.c_str());
-#else
   size_t oldN = wcstombs(NULL, oldname.c_str(), 0) + 1;
   char *oldfn = new char[oldN];
   wcstombs(oldfn, oldname.c_str(), oldN);
@@ -85,7 +71,6 @@ bool pws_os::RenameFile(const stringT &oldname, const stringT &newname)
   status = ::rename(oldfn, newfn);
   delete[] oldfn;
   delete[] newfn;
-#endif /* UNICODE */
   return (status == 0);
 }
 
@@ -94,10 +79,6 @@ bool pws_os::CopyAFile(const stringT &from, const stringT &to)
   const char *szfrom = NULL;
   const char *szto = NULL;
   bool retval = false;
-#ifndef UNICODE
-  szfrom = from.c_str();
-  szto = to.c_str();
-#else
   size_t fromsize = wcstombs(NULL, from.c_str(), 0) + 1;
   szfrom = new char[fromsize];
   wcstombs(const_cast<char *>(szfrom), from.c_str(), fromsize);
@@ -105,7 +86,6 @@ bool pws_os::CopyAFile(const stringT &from, const stringT &to)
   assert(tosize > 0);
   szto = new char[tosize];
   wcstombs(const_cast<char *>(szto), to.c_str(), tosize);
-#endif /* UNICODE */
   // can we read the source?
   bool readable = ::access(szfrom, R_OK) == 0;
   if (!readable) {
@@ -135,28 +115,20 @@ bool pws_os::CopyAFile(const stringT &from, const stringT &to)
     } while(readBytes != 0);
     retval = true;
   }
-#ifdef UNICODE
   delete[] szfrom;
   delete[] szto;
-#endif
   return retval;
 }
 
 bool pws_os::DeleteAFile(const stringT &filename)
 {
-#ifndef UNICODE
-  const char *szfn =  filename.c_str();
-#else
   size_t fnsize = wcstombs(NULL, filename.c_str(), 0) + 1;
   assert(fnsize > 0);
   const char *szfn = new char[fnsize];
   wcstombs(const_cast<char *>(szfn), filename.c_str(), fnsize);
-#endif /* UNICODE */
 
   bool retval = (::unlink(szfn) == 0);
-#ifdef UNICODE
   delete[] szfn;
-#endif
   return retval;
 }
 
@@ -173,18 +145,12 @@ void pws_os::FindFiles(const stringT &filter, vector<stringT> &res)
     return;
   // filter is a full path with a filter file name.
   const char *szfilter;
-#ifdef UNICODE
   size_t fltsize = wcstombs(NULL, filter.c_str(), 0) + 1;
   assert(fltsize > 0);
   szfilter = new char[fltsize];
   wcstombs(const_cast<char *>(szfilter), filter.c_str(), fltsize);
-#else
-  szfilter = filter.c_str();
-#endif /* UNICODE */
   string cfilter(szfilter);
-#ifdef UNICODE
   delete[] szfilter;
-#endif
   // start by splitting it up
   string dir;
   string::size_type last_slash = cfilter.find_last_of("/");
@@ -202,9 +168,6 @@ void pws_os::FindFiles(const stringT &filter, vector<stringT> &res)
   if (nMatches <= 0)
     return;
   while (nMatches-- != 0) {
-#ifndef UNICODE
-    res.push_back(namelist[nMatches]->d_name);
-#else
     size_t wname_len = ::mbstowcs(NULL,
                                   namelist[nMatches]->d_name,
                                   0) + 1;
@@ -212,7 +175,6 @@ void pws_os::FindFiles(const stringT &filter, vector<stringT> &res)
     mbstowcs(wname, namelist[nMatches]->d_name, wname_len);
     res.push_back(wname);
     delete[] wname;
-#endif
     free(namelist[nMatches]);
   }
   free(namelist);
@@ -235,13 +197,9 @@ bool pws_os::LockFile(const stringT &filename, stringT &locker,
   const stringT lock_filename = GetLockFileName(filename);
   stringT s_locker;
   bool retval = false;
-#ifndef UNICODE
-  const char *lfn = lock_filename.c_str();
-#else
   size_t lfs = wcstombs(NULL, lock_filename.c_str(), lock_filename.length()) + 1;
   char *lfn = new char[lfs];
   wcstombs(lfn, lock_filename.c_str(), lfs);
-#endif
   int fh = open(lfn, (O_CREAT | O_EXCL | O_WRONLY),
                  (S_IREAD | S_IWRITE));
 
@@ -288,11 +246,9 @@ bool pws_os::LockFile(const stringT &filename, stringT &locker,
                     lockStr.length() * sizeof(TCHAR));
     ASSERT(numWrit > 0);
     close(fh);
-    retval = true;
+    retval = (numWrit > 0);
   }
-#ifdef UNICODE
   delete[] lfn;
-#endif
   return retval;
 }
 
@@ -302,17 +258,11 @@ void pws_os::UnlockFile(const stringT &filename,
   UNREFERENCED_PARAMETER(lockFileHandle);
   UNREFERENCED_PARAMETER(LockCount);
   stringT lock_filename = GetLockFileName(filename);
-#ifndef UNICODE
-  const char *lfn = lock_filename.c_str();
-#else
   size_t lfs = wcstombs(NULL, lock_filename.c_str(), lock_filename.length()) + 1;
   char *lfn = new char[lfs];
   wcstombs(lfn, lock_filename.c_str(), lfs);
-#endif
   unlink(lfn);
-#ifdef UNICODE
   delete[] lfn;
-#endif
 }
 
 bool pws_os::IsLockedFile(const stringT &filename)
@@ -325,7 +275,6 @@ std::FILE *pws_os::FOpen(const stringT &filename, const TCHAR *mode)
 {
   const char *cfname = NULL;
   const char *cmode = NULL;
-#ifdef UNICODE
   size_t fnsize = wcstombs(NULL, filename.c_str(), 0) + 1;
   assert(fnsize > 1);
   cfname = new char[fnsize];
@@ -335,19 +284,13 @@ std::FILE *pws_os::FOpen(const stringT &filename, const TCHAR *mode)
   assert(modesize > 0);
   cmode = new char[modesize];
   wcstombs(const_cast<char *>(cmode), mode, modesize);
-#else
-  cfname = filename.c_str();
-  cmode = mode;
-#endif /* UNICODE */
   FILE *retval = ::fopen(cfname, cmode);
-#ifdef UNICODE
   delete[] cfname;
   delete[] cmode;
-#endif
   return retval;
 }
 
-long pws_os::fileLength(std::FILE *fp)
+ulong64 pws_os::fileLength(std::FILE *fp)
 {
   if (fp == NULL)
     return -1;
@@ -357,6 +300,6 @@ long pws_os::fileLength(std::FILE *fp)
   struct stat st;
   if (fstat(fd, &st) == -1)
     return -1;
-  return st.st_size;
+  return ulong64(st.st_size);
 }
 
