@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -20,13 +20,9 @@ struct tm *gmtime64_r(const __time64_t *timep, struct tm *result)
 
 int pws_os::asctime(TCHAR *s, size_t, tm const *t)
 {
-#ifdef UNICODE
   char cbuf[26]; // length specified in man (3) asctime
   asctime_r(t, cbuf);
   std::wstring wstr = pws_os::towc(cbuf);
   std::copy(wstr.begin(), wstr.end(), s);
-#else
-  asctime_r(t, s);
-#endif
   return 0;
 }
