@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -10,12 +10,15 @@
 
 #include "stdafx.h"
 #include "PasswordSafe.h"
+
 #include "ThisMfcApp.h"    // For Help
-#include "GeneralMsgBox.h"
 #include "DboxMain.h"
 
 #include "AddEdit_Additional.h"
 #include "AddEdit_PropertySheet.h"
+#include "GeneralMsgBox.h"
+
+#include "HKModifiers.h"
 
 #include "core/PWSprefs.h"
 #include "core/PWSAuxParse.h"
@@ -25,7 +28,7 @@
 
 using pws_os::CUUID;
 
-/////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////
 // CAddEdit_Additional property page
 
 IMPLEMENT_DYNAMIC(CAddEdit_Additional, CAddEdit_PropertyPage)
@@ -35,11 +38,28 @@ CAddEdit_Additional::CAddEdit_Additional(CWnd * pParent, st_AE_master_data *pAEM
                           CAddEdit_Additional::IDD, CAddEdit_Additional::IDD_SHORT,
                           pAEMD),
   m_ClearPWHistory(false), m_bSortAscending(true),
-  m_bInitdone(false), m_iSortedColumn(-1)
+  m_bInitdone(false), m_iSortedColumn(-1),
+  m_bWarnUserKBShortcut(false), m_iOldHotKey(0)
 {
   if (M_MaxPWHistory() == 0)
     M_MaxPWHistory() = PWSprefs::GetInstance()->
                            GetPref(PWSprefs::NumPWHistoryDefault);
+
+  // Save PWS HotKey info
+  int32 iPWSHotKeyValue = int32(PWSprefs::GetInstance()->GetPref(PWSprefs::HotKey));
+  m_wVirtualKeyCode = iPWSHotKeyValue & 0xff;
+  WORD wHKModifiers = iPWSHotKeyValue >> 16;
+  WORD wPWSModifiers = ConvertModifersMFC2PWS(wHKModifiers);
+  m_wModifiers = ConvertModifersMFC2Windows(wHKModifiers);
+
+  // Can't be enabled if not set!
+  if (iPWSHotKeyValue == 0) {
+    m_bPWSHotKeyEnabled = false;
+    m_iPWSAppHotKey = 0;
+  } else {
+    m_bPWSHotKeyEnabled = PWSprefs::GetInstance()->GetPref(PWSprefs::HotKeyEnabled);
+    m_iPWSAppHotKey = (wPWSModifiers << 16) + m_wVirtualKeyCode;
+  }
 }
 
 void CAddEdit_Additional::DoDataExchange(CDataExchange* pDX)
@@ -64,6 +84,11 @@ void CAddEdit_Additional::DoDataExchange(CDataExchange* pDX)
   DDX_Control(pDX, IDC_PWHISTORY_LIST, m_PWHistListCtrl);
   DDX_Check(pDX, IDC_SAVE_PWHIST, M_SavePWHistory());
   DDX_Text(pDX, IDC_MAXPWHISTORY, M_MaxPWHistory());
+
+  // Keyboard shortcut
+  DDX_Control(pDX, IDC_ENTKBSHCTHOTKEY, m_KBShortcutCtrl);
+  // Error/Warning messages for user defined keyboard shortcut
+  DDX_Control(pDX, IDC_STATIC_SHCTWARNING, m_stc_warning);
   //}}AFX_DATA_MAP
 }
 
@@ -75,6 +100,7 @@ BEGIN_MESSAGE_MAP(CAddEdit_Additional, CAddEdit_PropertyPage)
   ON_EN_CHANGE(IDC_AUTOTYPE, OnChanged)
   ON_EN_CHANGE(IDC_MAXPWHISTORY, OnChanged)
   ON_EN_CHANGE(IDC_RUNCMD, OnChanged)
+  ON_EN_CHANGE(IDC_ENTKBSHCTHOTKEY, OnHotKeyChanged)
 
   ON_CONTROL_RANGE(STN_CLICKED, IDC_STATIC_AUTO, IDC_STATIC_RUNCMD, OnSTCExClicked)
   ON_CBN_SELCHANGE(IDC_DOUBLE_CLICK_ACTION, OnDCAComboChanged)
@@ -88,6 +114,7 @@ BEGIN_MESSAGE_MAP(CAddEdit_Additional, CAddEdit_PropertyPage)
   ON_NOTIFY(HDN_ITEMCLICKA, 0, OnHeaderClicked)
   ON_NOTIFY(HDN_ITEMCLICKW, 0, OnHeaderClicked)
   ON_NOTIFY(NM_CLICK, IDC_PWHISTORY_LIST, OnHistListClick)
+  ON_NOTIFY(NM_DBLCLK, IDC_PWHISTORY_LIST, OnHistListClick)
 
   // Common
   ON_MESSAGE(PSM_QUERYSIBLINGS, OnQuerySiblings)
@@ -112,7 +139,10 @@ BOOL CAddEdit_Additional::OnInitDialog()
 {
   CAddEdit_PropertyPage::OnInitDialog();
 
-  ModifyStyleEx (0, WS_EX_CONTROLPARENT);
+  ModifyStyleEx(0, WS_EX_CONTROLPARENT);
+
+  m_stc_warning.SetColour(RGB(255, 0, 0));
+  m_stc_warning.ShowWindow(SW_HIDE);
 
   CString cs_dats;
   StringX sx_dats = PWSprefs::GetInstance()->
@@ -128,17 +158,37 @@ BOOL CAddEdit_Additional::OnInitDialog()
     InitToolTip();
     AddTool(IDC_STATIC_AUTO, IDS_CLICKTOCOPYEXPAND);
     AddTool(IDC_STATIC_RUNCMD, IDS_CLICKTOCOPYEXPAND);
+    AddTool(IDC_ENTKBSHCTHOTKEY, IDS_KBS_TOOLTIP0);
     ActivateToolTip();
 
     m_stc_autotype.SetHighlight(true, CAddEdit_PropertyPage::crefWhite);
     m_stc_runcommand.SetHighlight(true, CAddEdit_PropertyPage::crefWhite);
   }
 
+  m_KBShortcutCtrl.SetMyParent(this);
+
+  // These wil be zero for Add entry
+  WORD wVirtualKeyCode = M_KBShortcut() & 0xff;
+  WORD wPWSModifiers = M_KBShortcut() >> 16;
+
+  // Translate from PWS to CHotKeyCtrl modifiers
+  WORD wHKModifiers = ConvertModifersPWS2MFC(wPWSModifiers);
+
+  m_KBShortcutCtrl.SetHotKey(wVirtualKeyCode, wHKModifiers);
+
+  // We could do this to ensure user has at least Alt or Ctrl key
+  // But it gets changed without the user knowing - so we do it elsewhere
+  // instead and tell them.
+  //m_KBShortcutCtrl.SetRules(HKCOMB_NONE | HKCOMB_S, HOTKEYF_ALT);
+
   if (M_uicaller() == IDS_VIEWENTRY || M_protected() != 0) {
     // Disable normal Edit controls
     GetDlgItem(IDC_AUTOTYPE)->SendMessage(EM_SETREADONLY, TRUE, 0);
     GetDlgItem(IDC_RUNCMD)->SendMessage(EM_SETREADONLY, TRUE, 0);
 
+    // Disable HotKey
+    m_KBShortcutCtrl.EnableWindow(FALSE);
+
     // Disable Combobox
     GetDlgItem(IDC_DOUBLE_CLICK_ACTION)->EnableWindow(FALSE);
     GetDlgItem(IDC_SHIFT_DOUBLE_CLICK_ACTION)->EnableWindow(FALSE);
@@ -236,11 +286,7 @@ BOOL CAddEdit_Additional::OnInitDialog()
   m_PWHistListCtrl.SetRedraw(TRUE);
 
   wchar_t buffer[10];
-#if (_MSC_VER >= 1400)
-  swprintf_s(buffer, 10, L"%d", M_NumPWHistory());
-#else
-  swprintf(buffer, L"%d", M_NumPWHistory());
-#endif
+  swprintf_s(buffer, 10, L"%lu", M_NumPWHistory());
 
   if (M_original_entrytype() == CItemData::ET_ALIAS) {
     GetDlgItem(IDC_MAXPWHISTORY)->EnableWindow(FALSE);
@@ -250,6 +296,8 @@ BOOL CAddEdit_Additional::OnInitDialog()
     GetDlgItem(IDC_STATIC_OLDPW1)->EnableWindow(FALSE);
   }
 
+  m_stc_warning.SetColour(RGB(255, 0, 0));
+  m_stc_warning.ShowWindow(SW_HIDE);
   UpdateData(FALSE);
   m_bInitdone = true;
   return TRUE;
@@ -303,6 +351,24 @@ void CAddEdit_Additional::OnChanged()
   m_ae_psh->SetChanged(true);
 }
 
+void CAddEdit_Additional::OnHotKeyChanged()
+{
+  if (!m_bInitdone || m_AEMD.uicaller != IDS_EDITENTRY)
+    return;
+
+  UpdateData(TRUE);
+
+  WORD wVirtualKeyCode, wHKModifiers, wPWSModifiers;
+  m_KBShortcutCtrl.GetHotKey(wVirtualKeyCode, wHKModifiers);
+  
+  // Translate from PWS to CHotKeyCtrl modifiers
+  wPWSModifiers = ConvertModifersMFC2PWS(wHKModifiers);
+  int32 iKBShortcut = (wPWSModifiers << 16) + wVirtualKeyCode;
+
+  if (M_KBShortcut() != iKBShortcut)
+    m_ae_psh->SetChanged(true);
+}
+
 void CAddEdit_Additional::OnHelp()
 {
   ShowHelp(L"::/html/entering_pwd_add.html");
@@ -314,37 +380,46 @@ HBRUSH CAddEdit_Additional::OnCtlColor(CDC *pDC, CWnd *pWnd, UINT nCtlColor)
 
   // Only deal with Static controls and then
   // Only with our special ones
-  if (nCtlColor == CTLCOLOR_STATIC && M_uicaller() != IDS_ADDENTRY) {
-    COLORREF *pcfOld;
+  if (nCtlColor == CTLCOLOR_STATIC) {
     UINT nID = pWnd->GetDlgCtrlID();
-    switch (nID) {
-      case IDC_STATIC_AUTO:
-        pcfOld = &m_autotype_cfOldColour;
-        break;
-      case IDC_STATIC_RUNCMD:
-        pcfOld = &m_runcmd_cfOldColour;
-        break;
-      default:
-        // Not one of ours - get out quick
-        return hbr;
-        break;
+    if (nID == IDC_STATIC_SHCTWARNING) {
+      pDC->SetTextColor(RGB(255, 0, 0));
+      pDC->SetBkMode(TRANSPARENT);
+      return hbr;
     }
-    int iFlashing = ((CStaticExtn *)pWnd)->IsFlashing();
-    BOOL bHighlight = ((CStaticExtn *)pWnd)->IsHighlighted();
-    BOOL bMouseInWindow = ((CStaticExtn *)pWnd)->IsMouseInWindow();
 
-    if (iFlashing != 0) {
-      pDC->SetBkMode(iFlashing == 1 || (iFlashing && bHighlight && bMouseInWindow) ?
-                     OPAQUE : TRANSPARENT);
-      COLORREF cfFlashColour = ((CStaticExtn *)pWnd)->GetFlashColour();
-      *pcfOld = pDC->SetBkColor(iFlashing == 1 ? cfFlashColour : *pcfOld);
-    } else if (bHighlight) {
-      pDC->SetBkMode(bMouseInWindow ? OPAQUE : TRANSPARENT);
-      COLORREF cfHighlightColour = ((CStaticExtn *)pWnd)->GetHighlightColour();
-      *pcfOld = pDC->SetBkColor(bMouseInWindow ? cfHighlightColour : *pcfOld);
-    } else if (((CStaticExtn *)pWnd)->GetColourState()) {
-      COLORREF cfUser = ((CStaticExtn *)pWnd)->GetUserColour();
-      pDC->SetTextColor(cfUser);
+    if (M_uicaller() != IDS_ADDENTRY) {
+      COLORREF *pcfOld;
+      switch (nID) {
+        case IDC_STATIC_AUTO:
+          pcfOld = &m_autotype_cfOldColour;
+          break;
+        case IDC_STATIC_RUNCMD:
+          pcfOld = &m_runcmd_cfOldColour;
+          break;
+        default:
+          // Not one of ours - get out quick
+          return hbr;
+          break;
+      }
+
+      int iFlashing = ((CStaticExtn *)pWnd)->IsFlashing();
+      BOOL bHighlight = ((CStaticExtn *)pWnd)->IsHighlighted();
+      BOOL bMouseInWindow = ((CStaticExtn *)pWnd)->IsMouseInWindow();
+
+      if (iFlashing != 0) {
+        pDC->SetBkMode(iFlashing == 1 || (iFlashing && bHighlight && bMouseInWindow) ?
+                       OPAQUE : TRANSPARENT);
+        COLORREF cfFlashColour = ((CStaticExtn *)pWnd)->GetFlashColour();
+        *pcfOld = pDC->SetBkColor(iFlashing == 1 ? cfFlashColour : *pcfOld);
+      } else if (bHighlight) {
+        pDC->SetBkMode(bMouseInWindow ? OPAQUE : TRANSPARENT);
+        COLORREF cfHighlightColour = ((CStaticExtn *)pWnd)->GetHighlightColour();
+        *pcfOld = pDC->SetBkColor(bMouseInWindow ? cfHighlightColour : *pcfOld);
+      } else if (((CStaticExtn *)pWnd)->GetColourState()) {
+        COLORREF cfUser = ((CStaticExtn *)pWnd)->GetUserColour();
+        pDC->SetTextColor(cfUser);
+      }
     }
   }
 
@@ -357,9 +432,184 @@ BOOL CAddEdit_Additional::OnKillActive()
   if (UpdateData(TRUE) == FALSE)
     return FALSE;
 
+  if (CheckKeyboardShortcut() < 0 || m_bWarnUserKBShortcut)
+    return FALSE;
+
   return CAddEdit_PropertyPage::OnKillActive();
 }
 
+void CAddEdit_Additional::OnEntryHotKeyKillFocus()
+{
+  if (m_bPWSHotKeyEnabled)
+    return;
+
+  BOOL brc = RegisterHotKey(GetMainDlg()->m_hWnd, PWS_HOTKEY_ID,
+                            UINT(m_wModifiers), UINT(m_wVirtualKeyCode));
+  ASSERT(brc);
+
+  m_bPWSHotKeyEnabled = true;
+}
+
+void CAddEdit_Additional::OnEntryHotKeySetFocus()
+{
+  if (!m_bPWSHotKeyEnabled)
+    return;
+  
+  BOOL brc = UnregisterHotKey(GetMainDlg()->m_hWnd, PWS_HOTKEY_ID);
+  ASSERT(brc);
+  
+  m_bPWSHotKeyEnabled = false;
+}
+
+int CAddEdit_Additional::CheckKeyboardShortcut()
+{
+  if (m_AEMD.uicaller == IDS_VIEWENTRY)
+    return 0;
+
+  int32 iKBShortcut;
+  m_stc_warning.ShowWindow(SW_HIDE);
+  
+  WORD wVirtualKeyCode, wHKModifiers, wPWSModifiers;
+  m_KBShortcutCtrl.GetHotKey(wVirtualKeyCode, wHKModifiers);
+  
+  // Translate from CHotKeyCtrl to PWS modifiers
+  wPWSModifiers = ConvertModifersMFC2PWS(wHKModifiers);
+  iKBShortcut = (wPWSModifiers << 16) + wVirtualKeyCode ;
+
+  if (m_iOldHotKey != iKBShortcut)
+    m_bWarnUserKBShortcut = false;
+
+  if (iKBShortcut != 0) {
+    CString cs_errmsg, cs_msg;
+    
+    // Luckily for valid alphanumeric characters, Windows Virtual Key Code
+    // is the same as the ASCII character - no need for any conversion
+    static const wchar_t *wcValidKeys = 
+             L"0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+    if (wcschr(wcValidKeys, wVirtualKeyCode) == NULL) {
+      // Not alphanumeric
+      cs_msg.LoadString(IDS_KBS_INVALID);
+      m_stc_warning.SetWindowText(cs_msg);
+      m_stc_warning.ShowWindow(SW_SHOW);
+
+      // Reset keyboard shortcut
+      wVirtualKeyCode = wHKModifiers = wPWSModifiers = 0;
+      m_KBShortcutCtrl.SetHotKey(wVirtualKeyCode, wHKModifiers);
+      return KBSHORTCUT_INVALID_CHARACTER;
+    }
+
+    if (m_iPWSAppHotKey == iKBShortcut) {
+      // Same as PWS application HotKey
+      cs_msg.LoadString(IDS_KBS_SAMEASAPP);
+      m_stc_warning.SetWindowText(cs_msg);
+      m_stc_warning.ShowWindow(SW_SHOW);
+
+      // Reset keyboard shortcut
+      wVirtualKeyCode = wHKModifiers = wPWSModifiers = 0;
+      m_KBShortcutCtrl.SetHotKey(wVirtualKeyCode, wHKModifiers);
+      return KBSHORTCUT_IN_USE_BY_PWS;
+    }
+
+    if ((wPWSModifiers & PWS_HOTKEYF_ALT) == 0 &&
+        (wPWSModifiers & PWS_HOTKEYF_CONTROL) == 0 &&
+        !m_bWarnUserKBShortcut) {
+      // Add Alt and/or Ctrl key and tell user but first check not already in use
+      int iRC;
+      pws_os::CUUID chk_uuid;
+
+      WORD wValidModifierCombos[] = {
+                   PWS_HOTKEYF_ALT,
+                   PWS_HOTKEYF_ALT     | PWS_HOTKEYF_SHIFT,
+                   PWS_HOTKEYF_CONTROL,
+                   PWS_HOTKEYF_CONTROL | PWS_HOTKEYF_SHIFT,
+                   PWS_HOTKEYF_ALT     | PWS_HOTKEYF_CONTROL,
+                   PWS_HOTKEYF_ALT     | PWS_HOTKEYF_CONTROL | PWS_HOTKEYF_SHIFT};
+      int iActions[] = {IDS_KBS_ADD_ALT, IDS_KBS_ADD_ALTSHIFT,
+                        IDS_KBS_ADD_CTRL, IDS_KBS_ADD_CTRLSHIFT,
+                        IDS_KBS_ADD_ALTCTRL, IDS_KBS_ADD_ALTCTRLSHIFT};
+      
+      // Try them in order
+      int iChange, ierror(IDS_KBS_CANTADD);
+      for (iChange = 0; iChange < sizeof(wValidModifierCombos)/sizeof(WORD); iChange++) {
+        int iNewKBShortcut = ((wPWSModifiers | wValidModifierCombos[iChange]) << 16) + wVirtualKeyCode;
+        chk_uuid = M_pcore()->GetKBShortcut(iNewKBShortcut);
+        if (chk_uuid == CUUID::NullUUID() || chk_uuid == M_entry_uuid()) {
+          ierror = iActions[iChange];
+          break;
+        }
+      }
+
+      if (ierror == IDS_KBS_CANTADD) {
+        wVirtualKeyCode = wHKModifiers = wPWSModifiers = 0;
+        iRC = KBSHORTCUT_CANT_MAKE_UNIQUE;
+      } else {
+        wPWSModifiers |= wValidModifierCombos[iChange];
+        wHKModifiers = ConvertModifersPWS2MFC(wPWSModifiers);
+        iRC = KBSHORTCUT_MADE_UNIQUE;
+      }
+
+      cs_msg.LoadString(ierror);
+      cs_errmsg.Format(IDS_KBS_INVALID, cs_msg);
+      m_stc_warning.SetWindowText(cs_errmsg);
+      m_stc_warning.ShowWindow(SW_SHOW);
+
+      // Get new keyboard shortcut
+      m_iOldHotKey = iKBShortcut = (wPWSModifiers << 16) + wVirtualKeyCode;
+      ((CHotKeyCtrl *)GetDlgItem(IDC_ENTKBSHCTHOTKEY))->SetFocus();
+      m_bWarnUserKBShortcut = true;
+      m_KBShortcutCtrl.SetHotKey(wVirtualKeyCode, wHKModifiers);
+      return iRC;
+    }
+
+    const CString cs_HotKey = m_KBShortcutCtrl.GetHotKeyName();
+    pws_os::CUUID uuid = M_pcore()->GetKBShortcut(iKBShortcut);
+
+    if (uuid != CUUID::NullUUID() && uuid != M_entry_uuid()) {
+      // Tell user that it already exists as an entry keyboard shortcut
+      ItemListIter iter = M_pcore()->Find(uuid);
+      const StringX sxGroup = iter->second.GetGroup();
+      const StringX sxTitle = iter->second.GetTitle();
+      const StringX sxUser  = iter->second.GetUser();
+      CString cs_errmsg;
+      cs_errmsg.Format(IDS_KBS_INUSEBYENTRY, cs_HotKey,
+                       sxGroup.c_str(), sxTitle.c_str(), sxUser.c_str());
+      m_stc_warning.SetWindowText(cs_errmsg);
+      m_stc_warning.ShowWindow(SW_SHOW);
+
+      ((CHotKeyCtrl *)GetDlgItem(IDC_ENTKBSHCTHOTKEY))->SetFocus();
+
+      // Reset keyboard shortcut
+      wVirtualKeyCode = wHKModifiers = wPWSModifiers = 0;
+      m_KBShortcutCtrl.SetHotKey(wVirtualKeyCode, wHKModifiers);
+      return KBSHORTCUT_IN_USE_BY_ENTRY;
+    }
+    
+    StringX sxMenuItemName;
+    unsigned char ucModifiers = wHKModifiers & 0xff;
+    unsigned int nCID = GetMainDlg()->GetMenuShortcut(wVirtualKeyCode,
+                                                      ucModifiers, sxMenuItemName);
+    if (nCID != 0) {
+      // Save this value
+      m_iOldHotKey = iKBShortcut;
+
+      // Warn user that it is already in use for a menu item
+      // (on this instance for this user!)
+      Remove(sxMenuItemName, L'&');
+      CString cs_errmsg, cs_override(MAKEINTRESOURCE(IDS_ENTRYKBST_OVERRIDE));
+      cs_errmsg.Format(IDS_KBS_INUSEBYMENU, cs_HotKey, sxMenuItemName.c_str(), cs_override);
+      m_stc_warning.SetWindowText(cs_errmsg);
+      m_stc_warning.ShowWindow(SW_SHOW);
+      // We have warned them - so now accept
+      m_bWarnUserKBShortcut = !m_bWarnUserKBShortcut;
+      return KBSHORTCUT_IN_USE_BY_MENU;
+    }
+    // We have warned them - so now accept (we are here, if hotkey was made unique by adding modifier)
+    if (m_bWarnUserKBShortcut)
+      m_bWarnUserKBShortcut = false;
+  }
+  return KBSHORTCUT_UNIQUE;
+}
+
 LRESULT CAddEdit_Additional::OnQuerySiblings(WPARAM wParam, LPARAM )
 {
   UpdateData(TRUE);
@@ -377,7 +627,8 @@ LRESULT CAddEdit_Additional::OnQuerySiblings(WPARAM wParam, LPARAM )
           if (M_autotype()    != M_pci()->GetAutoType()   ||
               M_runcommand()  != M_pci()->GetRunCommand() ||
               M_DCA()         != M_oldDCA()               ||
-              M_ShiftDCA()    != M_oldShiftDCA())
+              M_ShiftDCA()    != M_oldShiftDCA()          ||
+              M_KBShortcut()  != M_oldKBShortcut())
             return 1L;
           break;
         case IDS_ADDENTRY:
@@ -411,6 +662,16 @@ BOOL CAddEdit_Additional::OnApply()
   M_autotype().EmptyIfOnlyWhiteSpace();
   M_runcommand().EmptyIfOnlyWhiteSpace();
 
+  if (CheckKeyboardShortcut() < 0 || m_bWarnUserKBShortcut)
+    return FALSE;
+
+  WORD wVirtualKeyCode, wHKModifiers, wPWSModifiers;
+  m_KBShortcutCtrl.GetHotKey(wVirtualKeyCode, wHKModifiers);
+  
+  // Translate from PWS to CHotKeyCtrl modifiers
+  wPWSModifiers = ConvertModifersMFC2PWS(wHKModifiers);
+  M_KBShortcut() = (wPWSModifiers << 16) + wVirtualKeyCode;
+
   if (M_runcommand().GetLength() > 0) {
     //Check Run Command parses - don't substitute
     std::wstring errmsg;
@@ -466,24 +727,20 @@ BOOL CAddEdit_Additional::OnApply()
 
   if (!(M_PWHistory().IsEmpty() && M_SavePWHistory() == FALSE)) {
     wchar_t buffer[6];
-#if (_MSC_VER >= 1400)
     swprintf_s(buffer, 6, L"%1x%02x%02x",
               (M_SavePWHistory() == FALSE) ? 0 : 1,
               M_MaxPWHistory(),
               M_pwhistlist().size());
-#else
-    swprintf(buffer, L"%1x%02x%02x",
-             (M_SavePWHistory() == FALSE) ? 0 : 1,
-             M_MaxPWHistory(),
-             M_pwhistlist().size());
-#endif
     if (M_PWHistory().GetLength() >= 5) {
-      for (int i = 0; i < 5; i++) M_PWHistory().SetAt(i, buffer[i]);
+      for (int i = 0; i < 5; i++) {
+        M_PWHistory().SetAt(i, buffer[i]);
+      }
     } else {
       M_PWHistory() = buffer;
     }
   }
 
+  m_iOldHotKey = M_KBShortcut();
   return CAddEdit_PropertyPage::OnApply();
 
 error:
@@ -561,8 +818,8 @@ void CAddEdit_Additional::OnSTCExClicked(UINT nID)
         sxData = PWSAuxParse::GetExpandedString(M_runcommand(),
                                                  M_currentDB(),
                                                  M_pci(),
-                                                 M_pDbx()->m_bDoAutoType,
-                                                 M_pDbx()->m_sxAutoType,
+                                                 GetMainDlg()->m_bDoAutoType,
+                                                 GetMainDlg()->m_sxAutoType,
                                                  errmsg, st_column, bURLSpecial);
         if (errmsg.length() > 0) {
           CGeneralMsgBox gmb;
@@ -577,8 +834,8 @@ void CAddEdit_Additional::OnSTCExClicked(UINT nID)
     default:
       ASSERT(0);
   }
-  M_pDbx()->SetClipboardData(sxData);
-  M_pDbx()->UpdateLastClipboardAction(iaction);
+  GetMainDlg()->SetClipboardData(sxData);
+  GetMainDlg()->UpdateLastClipboardAction(iaction);
 }
 
 void CAddEdit_Additional::OnCheckedSavePasswordHistory()
@@ -597,19 +854,6 @@ void CAddEdit_Additional::OnClearPWHist()
   m_ae_psh->SetChanged(true);
 }
 
-void CAddEdit_Additional::OnHistListClick(NMHDR *pNotifyStruct, LRESULT *)
-{
-  LPNMITEMACTIVATE lpnmitem = (LPNMITEMACTIVATE) pNotifyStruct;
-  ASSERT(lpnmitem != NULL);
-  int item = lpnmitem->iItem;
-  if (item == -1)
-    return;
-
-  size_t itempos = size_t(m_PWHistListCtrl.GetItemData(item));
-  const PWHistEntry pwhentry = M_pwhistlist()[itempos];
-  M_pDbx()->SetClipboardData(pwhentry.password);
-}
-
 void CAddEdit_Additional::OnHeaderClicked(NMHDR *pNotifyStruct, LRESULT *pLResult)
 {
   HD_NOTIFY *phdn = (HD_NOTIFY *) pNotifyStruct;
@@ -697,5 +941,18 @@ void CAddEdit_Additional::OnPWHCopyAll()
     HistStr += L"\r\n";
   }
 
-  M_pDbx()->SetClipboardData(HistStr);
+  GetMainDlg()->SetClipboardData(HistStr);
+}
+
+
+void CAddEdit_Additional::OnHistListClick(NMHDR *pNMHDR, LRESULT *pResult)
+{
+  LPNMITEMACTIVATE pNMItemActivate = reinterpret_cast<LPNMITEMACTIVATE>(pNMHDR);
+  int selectedRow = pNMItemActivate->iItem;
+  if (selectedRow >= 0) { // -1 means user doubleclicked on whitespace
+    int i = M_pwhistlist().size() - selectedRow - 1;
+    const StringX histpasswd = M_pwhistlist()[i].password;
+    GetMainDlg()->SetClipboardData(histpasswd);
+  }
+  *pResult = 0;
 }
