@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -19,12 +19,20 @@ IMPLEMENT_DYNAMIC(CAddEdit_PropertyPage, CPWPropertyPage)
 COLORREF CAddEdit_PropertyPage::crefGreen = (RGB(222, 255, 222));
 COLORREF CAddEdit_PropertyPage::crefWhite = (RGB(255, 255, 255));
 
-CAddEdit_PropertyPage::CAddEdit_PropertyPage(CWnd *pParent, UINT nID,
+CAddEdit_PropertyPage::CAddEdit_PropertyPage(CWnd *pParent,
+                                             UINT nID,
                                              st_AE_master_data *pAEMD)
- : CPWPropertyPage(nID), m_AEMD(*pAEMD)
+  : CPWPropertyPage(nID), m_AEMD(*pAEMD),
+    m_ae_psh((CAddEdit_PropertySheet *)pParent)
+{
+}
+
+CAddEdit_PropertyPage::CAddEdit_PropertyPage(CWnd *pParent,
+                                             UINT nID, UINT nID_Short,
+                                             st_AE_master_data *pAEMD)
+  : CPWPropertyPage(pAEMD->bLongPPs ? nID : nID_Short), m_AEMD(*pAEMD),
+    m_ae_psh((CAddEdit_PropertySheet *)pParent)
 {
-  // Save pointer to my PropertySheet
-  m_ae_psh = (CAddEdit_PropertySheet *)pParent;
 }
 
 BOOL CAddEdit_PropertyPage::OnQueryCancel()
