@@ -10,6 +10,7 @@
 
 #include "stdafx.h"
 #include "ControlExtns.h"
+#include "InfoDisplay.h"      // for Listbox Tooltips
 
 #include "core/ItemField.h" // for CSecEditExtn
 #include "core/BlowFish.h"  // ditto
@@ -1156,7 +1157,7 @@ LRESULT CSymbolEdit::OnPaste(WPARAM , LPARAM )
   }
   CloseClipboard();
 
-  CString cs_text, cs_oldtext;;
+  CString cs_text, cs_oldtext;
   GetWindowText(cs_text);
   cs_oldtext = cs_text;
 
