@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -35,77 +35,68 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
-static wchar_t PSSWDCHAR = L'*';
-
 //-----------------------------------------------------------------------------
 CPasskeyChangeDlg::CPasskeyChangeDlg(CWnd* pParent)
-  : CPWDialog(CPasskeyChangeDlg::IDD, pParent), m_pVKeyBoardDlg(NULL),
-  m_LastFocus(IDC_OLDPASSKEY)
+  : CPKBaseDlg(CPasskeyChangeDlg::IDD, pParent),
+    m_LastFocus(IDC_PASSKEY), m_Yubi1pressed(false), m_Yubi2pressed(false),
+    m_oldpasskeyConfirmed(false)
 {
-  m_oldpasskey = L"";
   m_newpasskey = L"";
   m_confirmnew = L"";
 
   m_pctlNewPasskey = new CSecEditExtn;
-  m_pctlOldPasskey = new CSecEditExtn;
   m_pctlConfirmNew = new CSecEditExtn;
 }
 
 CPasskeyChangeDlg::~CPasskeyChangeDlg()
 {
-  delete m_pctlOldPasskey;
   delete m_pctlNewPasskey;
   delete m_pctlConfirmNew;
-
-  if (m_pVKeyBoardDlg != NULL) {
-    // Save Last Used Keyboard
-    UINT uiKLID = m_pVKeyBoardDlg->GetKLID();
-    std::wostringstream os;
-    os.fill(L'0');
-    os << std::nouppercase << std::hex << std::setw(8) << uiKLID;
-    StringX cs_KLID = os.str().c_str();
-    PWSprefs::GetInstance()->SetPref(PWSprefs::LastUsedKeyboard, cs_KLID);
-
-    m_pVKeyBoardDlg->DestroyWindow();
-    delete m_pVKeyBoardDlg;
-  }
 }
 
 void CPasskeyChangeDlg::DoDataExchange(CDataExchange* pDX)
 {
-  CPWDialog::DoDataExchange(pDX);
+  CPKBaseDlg::DoDataExchange(pDX);
 
   // Can't use DDX_Text for CSecEditExtn
-  m_pctlOldPasskey->DoDDX(pDX, m_oldpasskey);
   m_pctlNewPasskey->DoDDX(pDX, m_newpasskey);
   m_pctlConfirmNew->DoDDX(pDX, m_confirmnew);
 
   DDX_Control(pDX, IDC_CONFIRMNEW, *m_pctlConfirmNew);
   DDX_Control(pDX, IDC_NEWPASSKEY, *m_pctlNewPasskey);
-  DDX_Control(pDX, IDC_OLDPASSKEY, *m_pctlOldPasskey);
+  DDX_Control(pDX, IDC_PASSKEY, *m_pctlPasskey);
 }
 
-BEGIN_MESSAGE_MAP(CPasskeyChangeDlg, CPWDialog)
+BEGIN_MESSAGE_MAP(CPasskeyChangeDlg, CPKBaseDlg)
   ON_BN_CLICKED(ID_HELP, OnHelp)
-  ON_EN_SETFOCUS(IDC_OLDPASSKEY, OnPasskeySetfocus)
+  ON_EN_SETFOCUS(IDC_PASSKEY, OnPasskeySetfocus)
   ON_EN_SETFOCUS(IDC_NEWPASSKEY, OnNewPasskeySetfocus)
   ON_EN_SETFOCUS(IDC_CONFIRMNEW, OnConfirmNewSetfocus)
   ON_STN_CLICKED(IDC_VKB, OnVirtualKeyboard)
   ON_MESSAGE(PWS_MSG_INSERTBUFFER, OnInsertBuffer)
+  ON_BN_CLICKED(IDC_YUBIKEY2_BTN, OnYubikey2Btn)
+  ON_BN_CLICKED(IDC_YUBIKEY_BTN, OnYubikeyBtn)
+  ON_WM_TIMER()
 END_MESSAGE_MAP()
 
 BOOL CPasskeyChangeDlg::OnInitDialog()
 {
-  CPWDialog::OnInitDialog();
+  CPKBaseDlg::OnInitDialog();
 
-  Fonts::GetInstance()->ApplyPasswordFont(GetDlgItem(IDC_OLDPASSKEY));
   Fonts::GetInstance()->ApplyPasswordFont(GetDlgItem(IDC_NEWPASSKEY));
   Fonts::GetInstance()->ApplyPasswordFont(GetDlgItem(IDC_CONFIRMNEW));
 
-  m_pctlOldPasskey->SetPasswordChar(PSSWDCHAR);
   m_pctlNewPasskey->SetPasswordChar(PSSWDCHAR);
   m_pctlConfirmNew->SetPasswordChar(PSSWDCHAR);
 
+  // Base class handles 1 Yubi btn, here we have 2, so we have to manage the
+  // 2nd on our lonely.
+  CButton *ybn2 = (CButton *)GetDlgItem(IDC_YUBIKEY2_BTN);
+  // Hide 2nd Yubi btn if Yubikey never detected
+  ybn2->ShowWindow(YubiExists() ? SW_SHOW : SW_HIDE);
+  // "Enable" 2nd Yubi btn iff Yubi's connected
+  ybn2->SetBitmap(IsYubiInserted() ? m_yubiLogo : m_yubiLogoDisabled);
+ 
   // Only show virtual Keyboard menu if we can load DLL
   if (!CVKeyBoardDlg::IsOSKAvailable()) {
     GetDlgItem(IDC_VKB)->ShowWindow(SW_HIDE);
@@ -115,14 +106,32 @@ BOOL CPasskeyChangeDlg::OnInitDialog()
   return TRUE;
 }
 
+void CPasskeyChangeDlg::yubiInserted(void)
+{
+  CPKBaseDlg::yubiInserted();
+  CButton *ybn2 = (CButton *)GetDlgItem(IDC_YUBIKEY2_BTN);
+  ybn2->ShowWindow(SW_SHOW); // needed for 1st time
+  ybn2->SetBitmap(m_yubiLogo);
+}
+
+void CPasskeyChangeDlg::yubiRemoved(void)
+{
+  CPKBaseDlg::yubiRemoved();
+  ((CButton *)GetDlgItem(IDC_YUBIKEY2_BTN))->SetBitmap(m_yubiLogoDisabled);
+}
+
 void CPasskeyChangeDlg::OnOK() 
 {
   StringX errmess;
   CString cs_msg, cs_text;
 
   UpdateData(TRUE);
+  if (!m_oldpasskey.IsEmpty()) {
+    m_passkey = m_oldpasskey; // old passkey is from Yubikey
+  }
+
   CGeneralMsgBox gmb;
-  int rc = app.m_core.CheckPasskey(app.m_core.GetCurFile(), m_oldpasskey);
+  int rc = app.GetCore()->CheckPasskey(app.GetCore()->GetCurFile(), m_passkey);
   if (rc == PWScore::WRONG_PASSWORD)
     gmb.AfxMessageBox(IDS_WRONGOLDPHRASE);
   else if (rc == PWScore::CANT_OPEN_FILE)
@@ -131,6 +140,7 @@ void CPasskeyChangeDlg::OnOK()
     gmb.AfxMessageBox(IDS_NEWOLDDONOTMATCH);
   else if (m_newpasskey.IsEmpty())
     gmb.AfxMessageBox(IDS_CANNOTBEBLANK);
+
   // Vox populi vox dei - folks want the ability to use a weak
   // passphrase, best we can do is warn them...
   // If someone want to build a version that insists on proper
@@ -139,25 +149,26 @@ void CPasskeyChangeDlg::OnOK()
   // (also used in CPasskeySetup)
   else if (!CPasswordCharPool::CheckPassword(m_newpasskey, errmess)) {
     cs_msg.Format(IDS_WEAKPASSPHRASE, errmess.c_str());
+
 #ifndef PWS_FORCE_STRONG_PASSPHRASE
     cs_text.LoadString(IDS_USEITANYWAY);
     cs_msg += cs_text;
     INT_PTR rc = gmb.AfxMessageBox(cs_msg, NULL, MB_YESNO | MB_ICONSTOP);
     if (rc == IDYES)
-      CPWDialog::OnOK();
+      CPKBaseDlg::OnOK();
 #else
     cs_text.LoadString(IDS_TRYANOTHER);
     cs_msg += cs_text;
     gmb.AfxMessageBox(cs_msg, NULL, MB_OK | MB_ICONSTOP);
 #endif // PWS_FORCE_STRONG_PASSPHRASE
   } else {
-    CPWDialog::OnOK();
+    CPKBaseDlg::OnOK();
   }
 }
 
 void CPasskeyChangeDlg::OnCancel() 
 {
-  CPWDialog::OnCancel();
+  CPKBaseDlg::OnCancel();
 }
 
 void CPasskeyChangeDlg::OnHelp() 
@@ -167,7 +178,7 @@ void CPasskeyChangeDlg::OnHelp()
 
 void CPasskeyChangeDlg::OnPasskeySetfocus()
 {
-  m_LastFocus = IDC_OLDPASSKEY;
+  m_LastFocus = IDC_PASSKEY;
 }
 
 void CPasskeyChangeDlg::OnNewPasskeySetfocus()
@@ -219,9 +230,9 @@ LRESULT CPasskeyChangeDlg::OnInsertBuffer(WPARAM, LPARAM)
   CSecString *m_pSecString;
 
   switch (m_LastFocus) {
-    case IDC_OLDPASSKEY:
-      m_pSecCtl = m_pctlOldPasskey;
-      m_pSecString = &m_oldpasskey;
+    case IDC_PASSKEY:
+      m_pSecCtl = m_pctlPasskey;
+      m_pSecString = &m_passkey;
       break;
     case IDC_NEWPASSKEY:
       m_pSecCtl = m_pctlNewPasskey;
@@ -257,3 +268,61 @@ LRESULT CPasskeyChangeDlg::OnInsertBuffer(WPARAM, LPARAM)
 
   return 0L;
 }
+
+void CPasskeyChangeDlg::OnYubikeyBtn()
+{
+  // This is for existing password verification
+  UpdateData(TRUE);
+  m_Yubi1pressed = true;
+  yubiRequestHMACSha1(m_passkey);
+}
+
+void CPasskeyChangeDlg::OnYubikey2Btn()
+{
+  UpdateData(TRUE);
+  if (m_confirmnew != m_newpasskey) {
+    CGeneralMsgBox gmb;
+    gmb.AfxMessageBox(IDS_NEWOLDDONOTMATCH);
+  } else {
+    m_Yubi2pressed = true;
+    m_oldpasskey = m_passkey; // might need for confirmation
+    m_passkey = m_newpasskey;
+    yubiRequestHMACSha1(m_newpasskey);
+  }
+}
+
+void CPasskeyChangeDlg::ProcessPhrase()
+{
+  if (m_Yubi1pressed) { // verify existing password
+    m_Yubi1pressed = false;
+    CGeneralMsgBox gmb;
+    int rc = app.GetCore()->CheckPasskey(app.GetCore()->GetCurFile(),
+                                         m_passkey);
+    if (rc == PWScore::WRONG_PASSWORD)
+      gmb.AfxMessageBox(IDS_WRONGOLDPHRASE);
+    else if (rc == PWScore::CANT_OPEN_FILE)
+      gmb.AfxMessageBox(IDS_CANTVERIFY);
+    else {
+      m_oldpasskey = m_passkey;
+      m_oldpasskeyConfirmed = true;
+    }
+  } else if (m_Yubi2pressed) { // set new yubi-passwd
+    m_Yubi2pressed = false;
+    if (!m_oldpasskeyConfirmed) {
+      // perhaps old passkey's w/o yubikey - check it that way
+      int rc = app.GetCore()->CheckPasskey(app.GetCore()->GetCurFile(),
+                                           m_oldpasskey);
+      m_oldpasskeyConfirmed = rc == PWScore::SUCCESS;
+    }
+    if (m_oldpasskeyConfirmed) {
+      // OnOK clears the passkey, so we save it
+      const CSecString save_passkey = m_passkey;
+      CPKBaseDlg::OnOK(); // skip our OnOK(), irrelevant
+      m_newpasskey = save_passkey;
+    } else {
+      m_yubi_status.SetWindowText(_T("Please confirm old passphrase"));
+    }
+  } else {
+    ASSERT(0);
+  }
+}
