@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -49,7 +49,6 @@ BOOL CFilterBoolDlg::OnInitDialog()
   CFilterBaseDlg::OnInitDialog();
 
   CString cs_text;
-  int iItem(-1);
 
   // NOTE: This ComboBox is NOT sorted by design !
   if (m_cbxRule.GetCount() == 0) {
@@ -78,7 +77,7 @@ BOOL CFilterBoolDlg::OnInitDialog()
     for (size_t i = 0; i < 2; i++) {
       UINT iumsg = PWSMatch::GetRule(pmrx[i]);
       cs_text.LoadString(iumsg);
-      iItem = m_cbxRule.AddString(cs_text);
+      int iItem = m_cbxRule.AddString(cs_text);
       m_cbxRule.SetItemData(iItem, pmrx[i]);
       m_rule2selection[pmrx[i]] = iItem;
     }
