@@ -1,5 +1,5 @@
       /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -226,7 +226,6 @@ BOOL CFilterDateDlg::OnInitDialog()
   CFilterBaseDlg::OnInitDialog();
 
   CString cs_text;
-  int iItem(-1);
 
   // NOTE: This ComboBox is NOT sorted by design !
   if (m_cbxRule.GetCount() == 0) {
@@ -236,7 +235,7 @@ BOOL CFilterDateDlg::OnInitDialog()
       for (size_t i = 0; i < _countof(mrx); i++) {
         UINT iumsg = PWSMatch::GetRule(mrx[i]);
         cs_text.LoadString(iumsg);
-        iItem = m_cbxRule.AddString(cs_text);
+        int iItem = m_cbxRule.AddString(cs_text);
         m_cbxRule.SetItemData(iItem, mrx[i]);
         m_rule2selection[mrx[i]] = iItem;
       }
@@ -248,7 +247,7 @@ BOOL CFilterDateDlg::OnInitDialog()
     for (size_t i = 0; i < _countof(mrx); i++) {
       UINT iumsg = PWSMatch::GetRule(mrx[i]);
       cs_text.LoadString(iumsg);
-      iItem = m_cbxRule.AddString(cs_text);
+      int iItem = m_cbxRule.AddString(cs_text);
       m_cbxRule.SetItemData(iItem, mrx[i]);
       m_rule2selection[mrx[i]] = iItem;
     }
